Only used for building deterministic blocks for legacy compatibility
NOT used for authoritative proof, instead rely on merkle proofs
NOT guaranteed to be globally unique
Any value which can cause a conflict or collision among nodes due to disagreements in ordering.
TODO: unify types here
An iterator over the variants of
ErrorShould this just be transactionInfo?
TODO: Might be best to just remove this entirely later and route it through transactions
These should both be broadcasts at some point
Consider using a response here if needed.
An iterator over the variants of
HashTypeAll of this is optional, used for external verifications
Generically typed value, used for storing arbitrary data in a common format.
Pre-claim deposit operation designating native multiparty groups to watch address for native deposits
Requires that the address on this network match the address of the external network, so that the private
key used for both is the same.
Native staking range to provide liquidity within. Trades cannot be executed outside of this range
Request to update external liquidity to a native pool
Request to withdraw liquidity from a pool
Same as KeyedTypedValue, but specific for matrix data.
Per node (machine) metadata, intended to be updated automatically by the hot key on the machine
An iterator over the variants of
NodeTypeTODO: Salt? Peer identifier? Etc
Derived data structure, not a primary chain data structure
Metadata associated with some node observing and validating data associated with some hash
For use in providing a secondary, recent, submission time for offline signing process with delayed broadcast.
Currently unused, but an optional anti-spam proof included in a transaction for increased mem-pool priority
Equivalent to a chainId identifier. Used as a marker for contracts or simplicity to indicate information
associated with the origin of a particular amount. Useful for schema-represented ERC-20 equivalent products.
Or other schema-driven contract definitions.
Witness data for a particular signing event, does not include the hash required to re-verify the information.
Compressed public key byte data (33 bytes for standard ECDSA)
The raw data associated with a signature, along with type information for how to verify it. Does not include
the public key associated with the signature, which is stored separately (unless the signature type contains
recovery id within the bytes.)
Generic data structure designed to hold arbitrary data in a common format.
This should be considered supplementary to using a regular schema, not a
complete substitute.
An iterator over the variants of
StateTODO: query selector
Information about the data type itself, such as time produced and hash representations of it
TODO: This should just return the entire transaction with it’s hash also calculated
Also include the signing hash in the response, modify transaction schema for that
monthly / daily / window size + window center
Only used temporarily for download, not reliable ‘time’ value
How to contact the node
Generically typed value class, used for representing arbitrary data
Derived data structure, not a primary chain data structure
Standard UTXO identifier similar to Bitcoin schema.