#[repr(i32)]
pub enum Error {
Show 31 variants IncorrectSignature = 0, MissingInputs = 1, MissingOutputs = 2, InvalidAddressInputIndex = 3, InvalidHashLength = 4, TransactionAlreadyProcessing = 5, UnknownUtxo = 6, BalanceMismatch = 7, InsufficientBalance = 8, InsufficientFee = 9, MissingProof = 10, TransactionRejectedDoubleSpend = 11, InternalDatabaseError = 12, AddressPublicKeyProofMismatch = 13, UnknownError = 14, DatabaseFailure = 15, MissingField = 16, ProtoDecoderFailure = 17, InvalidNetworkEnvironment = 18, DataStoreInternalCorruption = 19, HexDecodeFailure = 20, AddressDecodeFailure = 21, UnsupportedCurrency = 22, AddressNotFound = 23, UnknownTransaction = 24, UnknownBlock = 25, InternalChannelSendError = 26, InternalChannelReceiveError = 27, ParseFailure = 28, DeserializationFailure = 29, SerializationFailure = 30,
}

Variants



IncorrectSignature = 0



MissingInputs = 1



MissingOutputs = 2



InvalidAddressInputIndex = 3



InvalidHashLength = 4



TransactionAlreadyProcessing = 5



UnknownUtxo = 6



BalanceMismatch = 7



InsufficientBalance = 8



InsufficientFee = 9



MissingProof = 10



TransactionRejectedDoubleSpend = 11



InternalDatabaseError = 12



AddressPublicKeyProofMismatch = 13



UnknownError = 14



DatabaseFailure = 15



MissingField = 16



ProtoDecoderFailure = 17



InvalidNetworkEnvironment = 18



DataStoreInternalCorruption = 19



HexDecodeFailure = 20



AddressDecodeFailure = 21



UnsupportedCurrency = 22



AddressNotFound = 23



UnknownTransaction = 24



UnknownBlock = 25



InternalChannelSendError = 26



InternalChannelReceiveError = 27



ParseFailure = 28



DeserializationFailure = 29



SerializationFailure = 30

Implementations

source

impl Error

source

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of Error.

source

pub fn from_i32(value: i32) -> Option<Error>

Converts an i32 to a Error, or None if value is not a valid variant.