#[repr(i32)]pub enum NetworkEnvironment {
Main = 0,
Test = 1,
Dev = 2,
Staging = 3,
Perf = 4,
Integration = 5,
Local = 6,
Debug = 7,
All = 8,
Predev = 9,
}Variants
Main = 0
Production release, using real data and currency
Test = 1
Pre-production release, used for integration testing with release version before updating main net
Dev = 2
Latest dev branch code, continuously updated from latest build, unstable and non-release version
Staging = 3
Latest staging branch code, continuously updated but considered stable, upon verification is rolled to test net
Perf = 4
Performance testing network, used for debugging performance issues and not tied to a particular version or stage Can be manually set as for debugging, generally paired with staging code.
Integration = 5
Manually deployed network over arbitrary machines
Local = 6
Designation for an entire network running as local processes not connecting to external services
Debug = 7
Designation for an entire network running within a single process. Either with mock-ups or other testing harnesses – generally used for debugging within an IDE,
All = 8
Operations which can potentially span all networks, like a host manager or infrastructure configuration.
Predev = 9
Testing branch before dev, force push commits here for manual debugging, one user at a time.
Implementations
sourceimpl NetworkEnvironment
impl NetworkEnvironment
pub fn to_std_string(&self) -> String
pub fn parse(from_str: String) -> Self
pub fn parse_safe(from_str: String) -> Result<Self, ErrorInfo>
pub fn status_networks() -> Vec<NetworkEnvironment>
pub fn gui_networks() -> Vec<NetworkEnvironment>
pub fn local_debug(&self) -> bool
pub fn is_all(&self) -> bool
pub fn is_main(&self) -> bool
pub fn default_port_offset(&self) -> u16