Enum redgold_schema::structs::RatingType
source · #[repr(i32)]pub enum RatingType {
SecurityRating = 0,
DepositRating = 1,
}Variants
SecurityRating = 0
Conventional rating associated with likelihood to commit double spend or malicious node behavior
DepositRating = 1
Rating associated with multi-party computation, should always be strictly speaking more risky than normal security
Implementations