Struct redgold_schema::structs::AbridgedNodeMetadata
source · pub struct AbridgedNodeMetadata {
pub version_info: Option<VersionInfo>,
pub partition_info: Option<PartitionInfo>,
}Fields
version_info: Option<VersionInfo>partition_info: Option<PartitionInfo>Trait Implementations
sourceimpl Clone for AbridgedNodeMetadata
impl Clone for AbridgedNodeMetadata
sourcefn clone(&self) -> AbridgedNodeMetadata
fn clone(&self) -> AbridgedNodeMetadata
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AbridgedNodeMetadata
impl Debug for AbridgedNodeMetadata
sourceimpl Default for AbridgedNodeMetadata
impl Default for AbridgedNodeMetadata
sourceimpl<'de> Deserialize<'de> for AbridgedNodeMetadata
impl<'de> Deserialize<'de> for AbridgedNodeMetadata
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for AbridgedNodeMetadata
impl Hash for AbridgedNodeMetadata
sourceimpl Message for AbridgedNodeMetadata
impl Message for AbridgedNodeMetadata
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for AbridgedNodeMetadata
impl PartialEq for AbridgedNodeMetadata
sourcefn eq(&self, other: &AbridgedNodeMetadata) -> bool
fn eq(&self, other: &AbridgedNodeMetadata) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for AbridgedNodeMetadata
impl Serialize for AbridgedNodeMetadata
impl Eq for AbridgedNodeMetadata
impl StructuralEq for AbridgedNodeMetadata
impl StructuralPartialEq for AbridgedNodeMetadata