pub struct Address {
    pub address: Option<BytesData>,
    pub address_type: i32,
    pub currency: Option<i32>,
}

Fields

address: Option<BytesData>address_type: i32currency: Option<i32>

Implementations

source

impl Address

source

pub fn address_type(&self) -> AddressType

Returns the enum value of address_type, or the default if the field is set to an invalid enum value.

source

pub fn set_address_type(&mut self, value: AddressType)

Sets address_type to the provided enum value.

source

pub fn currency(&self) -> SupportedCurrency

Returns the enum value of currency, or the default if the field is unset or set to an invalid enum value.

source

pub fn set_currency(&mut self, value: SupportedCurrency)

Sets currency to the provided enum value.

source

impl Address

source

pub fn parse<S: Into<String>>(addr: S) -> Result<Address, ErrorInfo>

source

pub fn script_hash(input: impl AsRef<[u8]>) -> RgResult<Self>

source

pub fn from_bitcoin(address: &String) -> Address

source

pub fn is_bitcoin(&self) -> bool

source

pub fn render_string(&self) -> Result<String, ErrorInfo>

source

pub fn from_bytes(bytes: Vec<u8>) -> Result<Address, ErrorInfo>

source

pub fn from_struct_public(pk: &PublicKey) -> Result<Address, ErrorInfo>

source

pub fn with_checksum(bytes: Vec<u8>) -> Vec<u8>

source

pub fn hash(buf: &[u8]) -> Vec<u8>

source

pub fn verify_length(&self) -> Result<(), ErrorInfo>

source

pub fn verify_checksum(&self) -> Result<(), ErrorInfo>

source

pub fn str_to_address(s: String) -> Vec<u8>

source

pub fn address_to_str(a: &Vec<u8>) -> String

source

pub fn address_data(address: Vec<u8>) -> Option<Address>

source

pub fn new_raw(address: Vec<u8>) -> Address