Struct redgold_schema::structs::Block
source · pub struct Block {
pub merkle_root: Option<Hash>,
pub transactions: Vec<Transaction>,
pub struct_metadata: Option<StructMetadata>,
pub previous_block_hash: Option<Hash>,
pub metadata: Option<BlockMetadata>,
pub height: i64,
}Expand description
Only used for building deterministic blocks for legacy compatibility NOT used for authoritative proof, instead rely on merkle proofs NOT guaranteed to be globally unique
Fields
merkle_root: Option<Hash>transactions: Vec<Transaction>These are dropped for the hash calculation as the merkle root is present.
struct_metadata: Option<StructMetadata>previous_block_hash: Option<Hash>metadata: Option<BlockMetadata>height: i64Not really needed for hash calc, but harmless to include
Implementations