Struct redgold_schema::structs::BytesData
source · pub struct BytesData {
pub value: Vec<u8>,
pub decoder: i32,
pub version: i64,
}Fields
value: Vec<u8>decoder: i32version: i64Implementations
sourceimpl BytesData
impl BytesData
sourcepub fn decoder(&self) -> BytesDecoder
pub fn decoder(&self) -> BytesDecoder
Returns the enum value of decoder, or the default if the field is set to an invalid enum value.
sourcepub fn set_decoder(&mut self, value: BytesDecoder)
pub fn set_decoder(&mut self, value: BytesDecoder)
Sets decoder to the provided enum value.