Struct redgold_schema::structs::ContentionKey
source · pub struct ContentionKey {
pub utxo_id: Option<UtxoId>,
pub address: Option<Address>,
pub selector: Option<StateSelector>,
pub transaction_hash: Option<Hash>,
}Expand description
Any value which can cause a conflict or collision among nodes due to disagreements in ordering.
Fields
utxo_id: Option<UtxoId>Classical conflict condition associated with double spends, two transactions which share a common parent causing a conflict or contention.
address: Option<Address>Conflict conditions associated with deployed single-address contracts
selector: Option<StateSelector>Combined with above address – imposes a conflict ordering condition among a state subset denoted by a key index
transaction_hash: Option<Hash>Duplicate transaction hash conflict condition – associated with duplicate processing of same data. Primarily used internally for tracking internal contentions.
Implementations
sourceimpl ContentionKey
impl ContentionKey
pub fn contract_request( address: &Address, selector: Option<&StateSelector> ) -> ContentionKey