Struct redgold_schema::structs::ContractStateMarker
source · pub struct ContractStateMarker {
pub address: Option<Address>,
pub state: Option<BytesData>,
pub selector: Option<StateSelector>,
pub transaction_marker: Option<Hash>,
pub nonce: i64,
pub time: i64,
}Fields
address: Option<Address>state: Option<BytesData>selector: Option<StateSelector>transaction_marker: Option<Hash>nonce: i64time: i64Trait Implementations
sourceimpl Clone for ContractStateMarker
impl Clone for ContractStateMarker
sourcefn clone(&self) -> ContractStateMarker
fn clone(&self) -> ContractStateMarker
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ContractStateMarker
impl Debug for ContractStateMarker
sourceimpl Default for ContractStateMarker
impl Default for ContractStateMarker
sourceimpl<'de> Deserialize<'de> for ContractStateMarker
impl<'de> Deserialize<'de> for ContractStateMarker
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for ContractStateMarker
impl Hash for ContractStateMarker
sourceimpl Message for ContractStateMarker
impl Message for ContractStateMarker
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for ContractStateMarker
impl PartialEq for ContractStateMarker
sourcefn eq(&self, other: &ContractStateMarker) -> bool
fn eq(&self, other: &ContractStateMarker) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for ContractStateMarker
impl Serialize for ContractStateMarker
impl Eq for ContractStateMarker
impl StructuralEq for ContractStateMarker
impl StructuralPartialEq for ContractStateMarker