Struct redgold_schema::structs::DepositAddress
source · pub struct DepositAddress {
pub address: Option<Address>,
pub owner: Option<PublicKey>,
}Fields
address: Option<Address>Multi-sig / t-ECDSA address
owner: Option<PublicKey>If present, the public key associated with the address coordinator, if empty, the address is coordinated by self.