pub struct ErrorInfo {
    pub code: i32,
    pub description: String,
    pub description_extended: String,
    pub message: String,
    pub details: Vec<ErrorDetails>,
    pub retriable: bool,
    pub stacktrace: String,
    pub lib_message: String,
    pub abort: bool,
}

Fields

code: i32description: Stringdescription_extended: Stringmessage: Stringdetails: Vec<ErrorDetails>retriable: boolstacktrace: Stringlib_message: Stringabort: bool

Implementations

source

impl ErrorInfo

source

pub fn code(&self) -> Error

Returns the enum value of code, or the default if the field is set to an invalid enum value.

source

pub fn set_code(&mut self, value: Error)

Sets code to the provided enum value.

source

impl ErrorInfo

source

pub fn error_info<S: Into<String>>(message: S) -> ErrorInfo

source

pub fn new(message: impl Into<String>) -> ErrorInfo

source

pub fn response_metadata(self) -> ResponseMetadata

source

pub fn enhance(self, message: impl Into<String>) -> ErrorInfo