Struct redgold_schema::structs::ExternalTransactionId
source · pub struct ExternalTransactionId {
pub identifier: String,
}Fields
identifier: StringTrait Implementations
sourceimpl Clone for ExternalTransactionId
impl Clone for ExternalTransactionId
sourcefn clone(&self) -> ExternalTransactionId
fn clone(&self) -> ExternalTransactionId
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ExternalTransactionId
impl Debug for ExternalTransactionId
sourceimpl Default for ExternalTransactionId
impl Default for ExternalTransactionId
sourceimpl<'de> Deserialize<'de> for ExternalTransactionId
impl<'de> Deserialize<'de> for ExternalTransactionId
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for ExternalTransactionId
impl Hash for ExternalTransactionId
sourceimpl Message for ExternalTransactionId
impl Message for ExternalTransactionId
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for ExternalTransactionId
impl PartialEq for ExternalTransactionId
sourcefn eq(&self, other: &ExternalTransactionId) -> bool
fn eq(&self, other: &ExternalTransactionId) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for ExternalTransactionId
impl Serialize for ExternalTransactionId
impl Eq for ExternalTransactionId
impl StructuralEq for ExternalTransactionId
impl StructuralPartialEq for ExternalTransactionId