Struct redgold_schema::structs::GenericTypedValue
source · pub struct GenericTypedValue {
pub typed_value: Option<TypedValue>,
pub typed_value_list: Vec<TypedValue>,
pub keyed_typed_value: Option<KeyedTypedValue>,
pub keyed_typed_value_list: Vec<KeyedTypedValue>,
pub matrix_typed_value: Option<MatrixTypedValue>,
pub matrix_typed_value_list: Vec<MatrixTypedValue>,
}Fields
typed_value: Option<TypedValue>typed_value_list: Vec<TypedValue>keyed_typed_value: Option<KeyedTypedValue>keyed_typed_value_list: Vec<KeyedTypedValue>matrix_typed_value: Option<MatrixTypedValue>matrix_typed_value_list: Vec<MatrixTypedValue>Trait Implementations
sourceimpl Clone for GenericTypedValue
impl Clone for GenericTypedValue
sourcefn clone(&self) -> GenericTypedValue
fn clone(&self) -> GenericTypedValue
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for GenericTypedValue
impl Debug for GenericTypedValue
sourceimpl Default for GenericTypedValue
impl Default for GenericTypedValue
sourceimpl<'de> Deserialize<'de> for GenericTypedValue
impl<'de> Deserialize<'de> for GenericTypedValue
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for GenericTypedValue
impl Hash for GenericTypedValue
sourceimpl Message for GenericTypedValue
impl Message for GenericTypedValue
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for GenericTypedValue
impl PartialEq for GenericTypedValue
sourcefn eq(&self, other: &GenericTypedValue) -> bool
fn eq(&self, other: &GenericTypedValue) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for GenericTypedValue
impl Serialize for GenericTypedValue
impl Eq for GenericTypedValue
impl StructuralEq for GenericTypedValue
impl StructuralPartialEq for GenericTypedValue