pub struct Hash {
    pub bytes: Option<BytesData>,
    pub hash_format_type: i32,
    pub hash_type: i32,
}

Fields

bytes: Option<BytesData>hash_format_type: i32hash_type: i32

Implementations

source

impl Hash

source

pub fn hash_format_type(&self) -> HashFormatType

Returns the enum value of hash_format_type, or the default if the field is set to an invalid enum value.

source

pub fn set_hash_format_type(&mut self, value: HashFormatType)

Sets hash_format_type to the provided enum value.

source

pub fn hash_type(&self) -> HashType

Returns the enum value of hash_type, or the default if the field is set to an invalid enum value.

source

pub fn set_hash_type(&mut self, value: HashType)

Sets hash_type to the provided enum value.

source

impl Hash

source

pub fn vec(&self) -> Vec<u8>

source

pub fn hex(&self) -> String

source

pub fn new(vec: Vec<u8>) -> Self

source

pub fn validate_size(&self) -> Result<&Self, ErrorInfo>

source

pub fn from_hex<S: Into<String>>(s: S) -> Result<Self, ErrorInfo>

source

pub fn from_string_calculate(s: &str) -> Self

source

pub fn digest(s: Vec<u8>) -> Self

source

pub fn div_mod(&self, bucket: usize) -> i64

source

pub fn merkle_combine(&self, right: Hash) -> Self

source

pub fn checksum(&self) -> Result<Vec<u8>, ErrorInfo>

source

pub fn checksum_hex(&self) -> Result<String, ErrorInfo>

source

pub fn xor_vec(&self, other: Hash) -> RgResult<Vec<u8>>

source

pub fn xor_distance(&self, other: Hash) -> RgResult<u64>

source

pub fn new_checksum(s: &Vec<u8>) -> RgResult<String>