pub struct IdentityMetadata {
    pub github_username: Option<String>,
    pub website: Option<String>,
    pub full_name: Option<String>,
    pub username: Option<String>,
    pub email: Option<String>,
    pub discord_id: Option<String>,
    pub twitter: Option<String>,
}
All of this is optional, used for external verifications

Fields

github_username: Option<String>website: Option<String>full_name: Option<String>username: Option<String>email: Option<String>discord_id: Option<String>twitter: Option<String>

Implementations

source

impl IdentityMetadata

source

pub fn github_username(&self) -> &str

Returns the value of github_username, or the default value if github_username is unset.

source

pub fn website(&self) -> &str

Returns the value of website, or the default value if website is unset.

source

pub fn full_name(&self) -> &str

Returns the value of full_name, or the default value if full_name is unset.

source

pub fn username(&self) -> &str

Returns the value of username, or the default value if username is unset.

source

pub fn email(&self) -> &str

Returns the value of email, or the default value if email is unset.

source

pub fn discord_id(&self) -> &str

Returns the value of discord_id, or the default value if discord_id is unset.

source

pub fn twitter(&self) -> &str

Returns the value of twitter, or the default value if twitter is unset.