Struct redgold_schema::structs::Input
source · pub struct Input {
pub utxo_id: Option<UtxoId>,
pub proof: Vec<Proof>,
pub product_id: Option<ProductId>,
pub output: Option<Output>,
pub floating_utxo_id: Option<FloatingUtxoId>,
pub input_type: Option<i32>,
}Fields
utxo_id: Option<UtxoId>proof: Vec<Proof>The signed proof that this input is a valid reference to the previous output.
product_id: Option<ProductId>The identifier associated with the currency or product being used, for multi-currency support.
output: Option<Output>Hydration purposes only! Not used for hashes
floating_utxo_id: Option<FloatingUtxoId>input_type: Option<i32>Implementations
sourceimpl Input
impl Input
sourcepub fn input_type(&self) -> InputType
pub fn input_type(&self) -> InputType
Returns the enum value of input_type, or the default if the field is unset or set to an invalid enum value.
sourcepub fn set_input_type(&mut self, value: InputType)
pub fn set_input_type(&mut self, value: InputType)
Sets input_type to the provided enum value.