Struct redgold_schema::structs::LiquidityDeposit
source · pub struct LiquidityDeposit {
pub liquidity_ranges: Vec<LiquidityRange>,
}Expand description
Pre-claim deposit operation designating native multiparty groups to watch address for native deposits Requires that the address on this network match the address of the external network, so that the private key used for both is the same.
Fields
liquidity_ranges: Vec<LiquidityRange>Each value should be a uniquely defined, non-overlapping range of liquidity to provide within