pub struct LiquidityRange {
    pub min_inclusive: Option<CurrencyAmount>,
    pub max_exclusive: Option<CurrencyAmount>,
    pub allow_dynamic_fee: bool,
    pub desired_fee_fraction: Option<Weighting>,
    pub allocation_fraction: Option<Weighting>,
}
Native staking range to provide liquidity within. Trades cannot be executed outside of this range

Fields

min_inclusive: Option<CurrencyAmount>

No trades can be executed below this amount

max_exclusive: Option<CurrencyAmount>

No trades can be executed above this amount

allow_dynamic_fee: bool

Whether or not to allow dynamic fee calculation

desired_fee_fraction: Option<Weighting>

Minimum fees required to be collected for this range

allocation_fraction: Option<Weighting>

How much of the total input staking quantity to allocate to this range