Struct redgold_schema::structs::MultipartyBroadcast
source · pub struct MultipartyBroadcast {
pub room_id: String,
pub message: String,
}Fields
room_id: Stringmessage: StringTrait Implementations
sourceimpl Clone for MultipartyBroadcast
impl Clone for MultipartyBroadcast
sourcefn clone(&self) -> MultipartyBroadcast
fn clone(&self) -> MultipartyBroadcast
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for MultipartyBroadcast
impl Debug for MultipartyBroadcast
sourceimpl Default for MultipartyBroadcast
impl Default for MultipartyBroadcast
sourceimpl<'de> Deserialize<'de> for MultipartyBroadcast
impl<'de> Deserialize<'de> for MultipartyBroadcast
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for MultipartyBroadcast
impl Hash for MultipartyBroadcast
sourceimpl Message for MultipartyBroadcast
impl Message for MultipartyBroadcast
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for MultipartyBroadcast
impl PartialEq for MultipartyBroadcast
sourcefn eq(&self, other: &MultipartyBroadcast) -> bool
fn eq(&self, other: &MultipartyBroadcast) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for MultipartyBroadcast
impl Serialize for MultipartyBroadcast
impl Eq for MultipartyBroadcast
impl StructuralEq for MultipartyBroadcast
impl StructuralPartialEq for MultipartyBroadcast