Struct redgold_schema::structs::NodeMetadata
source · pub struct NodeMetadata {
pub transport_info: Option<TransportInfo>,
pub public_key: Option<PublicKey>,
pub node_type: Option<i32>,
pub version_info: Option<VersionInfo>,
pub partition_info: Option<PartitionInfo>,
pub node_name: Option<String>,
pub peer_id: Option<PeerId>,
pub deposit_addresses: Vec<DepositAddress>,
}Expand description
Per node (machine) metadata, intended to be updated automatically by the hot key on the machine
Fields
transport_info: Option<TransportInfo>Information about how to contact the node
public_key: Option<PublicKey>Public key associated with the node signatures for real-time signatures, such as observations
node_type: Option<i32>What type of node this is, in terms of whether it stays online consistently or is ephemeral and can’t be relied upon to be continuously online.
version_info: Option<VersionInfo>Information about the executable and other checksums, also used for coordinating upgrades
partition_info: Option<PartitionInfo>Distances to various types of hashes for partitioning and storage of data. Used for optimizing gossip and long term storage.
node_name: Option<String>Identifier for the particular machine, not guaranteed to be unique across network. Public key should be used primarily, this is only for convenience.
peer_id: Option<PeerId>Corresponding public key of the overall identity controlling this, and other nodes
deposit_addresses: Vec<DepositAddress>Implementations
sourceimpl NodeMetadata
impl NodeMetadata
sourceimpl NodeMetadata
impl NodeMetadata
pub fn port_or(&self, network: NetworkEnvironment) -> u16
pub fn public_key_bytes(&self) -> Result<Vec<u8>, ErrorInfo>
pub fn long_identifier(&self) -> String
pub fn external_address(&self) -> RgResult<String>
pub fn tx_in_range(&self, h: &Hash) -> bool
pub fn hash_in_range( &self, h: &Hash, f: fn(_: &PartitionInfo) -> Option<i64> ) -> bool