pub struct ObservationMetadata {
    pub observed_hash: Option<Hash>,
    pub observation_type: i32,
    pub state: i32,
    pub validation_confidence: Option<TrustData>,
    pub struct_metadata: Option<StructMetadata>,
    pub validation_liveness: i32,
    pub liveness_confidence: Option<TrustData>,
}
Metadata associated with some node observing and validating data associated with some hash

Fields

observed_hash: Option<Hash>

The data under consideration which has had some validation performed for it.

observation_type: i32

Whether or not we have fully resolved all prior dependencies associated with the data internally

state: i32

How much we have accepted this data, whether or not sufficient time has passed to consider it confirmed

validation_confidence: Option<TrustData>

The degree of certainty associated with our validation, based on trustworthiness of information received from other peers

struct_metadata: Option<StructMetadata>

Information about this object itself, such as time produced and hash representations of it

validation_liveness: i32

Whether or not we consider this data already confirmed, or in process.

liveness_confidence: Option<TrustData>

How certain we are of the liveness.

Implementations

source

impl ObservationMetadata

source

pub fn observation_type(&self) -> ValidationType

Returns the enum value of observation_type, or the default if the field is set to an invalid enum value.

source

pub fn set_observation_type(&mut self, value: ValidationType)

Sets observation_type to the provided enum value.

source

pub fn state(&self) -> State

Returns the enum value of state, or the default if the field is set to an invalid enum value.

source

pub fn set_state(&mut self, value: State)

Sets state to the provided enum value.

source

pub fn validation_liveness(&self) -> ValidationLiveness

Returns the enum value of validation_liveness, or the default if the field is set to an invalid enum value.

source

pub fn set_validation_liveness(&mut self, value: ValidationLiveness)

Sets validation_liveness to the provided enum value.