Struct redgold_schema::structs::ObservationProof
source · pub struct ObservationProof {
pub observation_hash: Option<Hash>,
pub merkle_proof: Option<MerkleProof>,
pub metadata: Option<ObservationMetadata>,
pub proof: Option<Proof>,
}Fields
observation_hash: Option<Hash>Transaction hash associated with the observation
merkle_proof: Option<MerkleProof>Proof of this particular observation within the merkle root of the observation
metadata: Option<ObservationMetadata>proof: Option<Proof>Trait Implementations
sourceimpl Clone for ObservationProof
impl Clone for ObservationProof
sourcefn clone(&self) -> ObservationProof
fn clone(&self) -> ObservationProof
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ObservationProof
impl Debug for ObservationProof
sourceimpl Default for ObservationProof
impl Default for ObservationProof
sourceimpl<'de> Deserialize<'de> for ObservationProof
impl<'de> Deserialize<'de> for ObservationProof
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for ObservationProof
impl Hash for ObservationProof
sourceimpl Message for ObservationProof
impl Message for ObservationProof
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for ObservationProof
impl PartialEq for ObservationProof
sourcefn eq(&self, other: &ObservationProof) -> bool
fn eq(&self, other: &ObservationProof) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for ObservationProof
impl Serialize for ObservationProof
impl Eq for ObservationProof
impl StructuralEq for ObservationProof
impl StructuralPartialEq for ObservationProof