pub struct Output {
    pub address: Option<Address>,
    pub product_id: Option<ProductId>,
    pub counter_party_proofs: Vec<Proof>,
    pub data: Option<StandardData>,
    pub contract: Option<OutputContract>,
    pub output_type: Option<i32>,
    pub utxo_id: Option<UtxoId>,
}

Fields

address: Option<Address>

Basic unlock condition for using this as a consumable input. Script hash or hash of a public key.

product_id: Option<ProductId>counter_party_proofs: Vec<Proof>data: Option<StandardData>

change to outputData?

contract: Option<OutputContract>output_type: Option<i32>utxo_id: Option<UtxoId>

Used for specifying UTXO contract reference as well as address.

Implementations

source

impl Output

source

pub fn output_type(&self) -> OutputType

Returns the enum value of output_type, or the default if the field is unset or set to an invalid enum value.

source

pub fn set_output_type(&mut self, value: OutputType)

Sets output_type to the provided enum value.

source

impl Output

source

pub fn is_request(&self) -> bool

source

pub fn is_deploy(&self) -> bool

source

pub fn code(&self) -> Option<Vec<u8>>

source

pub fn validate_deploy_code(&self) -> RgResult<Vec<u8>>

source

pub fn pay_update_descendents(&self) -> bool

source

pub fn request_data(&self) -> RgResult<&Vec<u8>>

source

pub fn request_contention_key(&self) -> RgResult<ContentionKey>

source

pub fn request_selector(&self) -> RgResult<Option<&StateSelector>>

source

pub fn new(address: &Address, amount: i64) -> Output

source

pub fn from_data(data: StandardData) -> Self

source

pub fn is_swap(&self) -> bool

source

pub fn is_peer_data(&self) -> bool

source

pub fn is_liquidity(&self) -> bool

source

pub fn utxo_entry( &self, transaction_hash: &Hash, output_index: i64, time: i64 ) -> UtxoEntry

source

pub fn amount(&self) -> u64

source

pub fn amount_i64(&self) -> i64

source

pub fn safe_ensure_amount(&self) -> Result<&i64, ErrorInfo>

source

pub fn observation(&self) -> RgResult<&Observation>

source

pub fn opt_amount(&self) -> Option<i64>

source

pub fn opt_amount_typed(&self) -> Option<CurrencyAmount>

source

pub fn rounded_amount(&self) -> f64