pub struct OutputContract {
    pub standard_contract_type: Option<i32>,
    pub code_execution_contract: Option<CodeExecutionContract>,
    pub threshold: Option<i64>,
    pub weights: Vec<i64>,
    pub pay_update_descendents: bool,
    pub consumable: bool,
}

Fields

standard_contract_type: Option<i32>

hash references, same issue as other thing

code_execution_contract: Option<CodeExecutionContract>threshold: Option<i64>weights: Vec<i64>pay_update_descendents: bool

What was this for? Are we ever gonna send to an address filter predicate that is different from the output address? Address filter_predicate_destination = 5;

consumable: bool

Implementations

source

impl OutputContract

source

pub fn standard_contract_type(&self) -> StandardContractType

Returns the enum value of standard_contract_type, or the default if the field is unset or set to an invalid enum value.

source

pub fn set_standard_contract_type(&mut self, value: StandardContractType)

Sets standard_contract_type to the provided enum value.

source

pub fn threshold(&self) -> i64

Returns the value of threshold, or the default value if threshold is unset.