pub struct PartitionInfo {
    pub utxo: Option<i64>,
    pub contract_address: Option<i64>,
    pub transaction_hash: Option<i64>,
    pub address: Option<i64>,
}

Fields

utxo: Option<i64>contract_address: Option<i64>transaction_hash: Option<i64>address: Option<i64>

Implementations

source

impl PartitionInfo

source

pub fn utxo(&self) -> i64

Returns the value of utxo, or the default value if utxo is unset.

source

pub fn contract_address(&self) -> i64

Returns the value of contract_address, or the default value if contract_address is unset.

source

pub fn transaction_hash(&self) -> i64

Returns the value of transaction_hash, or the default value if transaction_hash is unset.

source

pub fn address(&self) -> i64

Returns the value of address, or the default value if address is unset.