Struct redgold_schema::structs::PoWProof
source · pub struct PoWProof {
pub proof_type: i32,
pub nonce: Option<BytesData>,
}Expand description
Currently unused, but an optional anti-spam proof included in a transaction for increased mem-pool priority
Fields
proof_type: i32nonce: Option<BytesData>Implementations
sourceimpl PoWProof
impl PoWProof
sourcepub fn proof_type(&self) -> PoWProofType
pub fn proof_type(&self) -> PoWProofType
Returns the enum value of proof_type, or the default if the field is set to an invalid enum value.
sourcepub fn set_proof_type(&mut self, value: PoWProofType)
pub fn set_proof_type(&mut self, value: PoWProofType)
Sets proof_type to the provided enum value.