Struct redgold_schema::structs::PortfolioWeighting
source · pub struct PortfolioWeighting {
pub currency: Option<i32>,
pub product_id: Option<ProductId>,
pub weight: Option<Weighting>,
}Fields
currency: Option<i32>product_id: Option<ProductId>weight: Option<Weighting>Implementations
sourceimpl PortfolioWeighting
impl PortfolioWeighting
sourcepub fn currency(&self) -> SupportedCurrency
pub fn currency(&self) -> SupportedCurrency
Returns the enum value of currency, or the default if the field is unset or set to an invalid enum value.
sourcepub fn set_currency(&mut self, value: SupportedCurrency)
pub fn set_currency(&mut self, value: SupportedCurrency)
Sets currency to the provided enum value.