Struct redgold_schema::structs::ProductId
source · pub struct ProductId {
pub network: Option<Hash>,
pub product: Option<Hash>,
}Expand description
Equivalent to a chainId identifier. Used as a marker for contracts or simplicity to indicate information associated with the origin of a particular amount. Useful for schema-represented ERC-20 equivalent products. Or other schema-driven contract definitions.
Fields
network: Option<Hash>Used to represent off-chain products
product: Option<Hash>Used to represent on-chain products