Struct redgold_schema::structs::Proof
source · pub struct Proof {
pub signature: Option<Signature>,
pub public_key: Option<PublicKey>,
}Expand description
Witness data for a particular signing event, does not include the hash required to re-verify the information.
Fields
signature: Option<Signature>Raw signing data, associated with the signature of a particular, individual hash, typically a transaction hash
public_key: Option<PublicKey>The public key of the key that produced this signature, required to verify the signature in the event the signature type does not implement a recovery id.
Implementations
sourceimpl Proof
impl Proof
pub fn signature_hex(&self) -> RgResult<String>
pub fn public_key_bytes(&self) -> Result<Vec<u8>, ErrorInfo>
pub fn signature_bytes(&self) -> Result<Vec<u8>, ErrorInfo>
pub fn proofs_to_address(proofs: &Vec<Proof>) -> Result<Address, ErrorInfo>
pub fn from(public_key: PublicKey, signature: Signature) -> Self