pub struct PublicKey {
    pub bytes: Option<BytesData>,
    pub key_type: i32,
}
Compressed public key byte data (33 bytes for standard ECDSA)

Fields

bytes: Option<BytesData>

Encoded data form of the public key, requires a library for decoding to appropriate key instance

key_type: i32

The type of public key, used to determine how to decode the bytes into a key instance

Implementations

source

impl PublicKey

source

pub fn key_type(&self) -> PublicKeyType

Returns the enum value of key_type, or the default if the field is set to an invalid enum value.

source

pub fn set_key_type(&mut self, value: PublicKeyType)

Sets key_type to the provided enum value.

source

impl PublicKey

source

pub fn from_bytes(bytes: Vec<u8>) -> Self

source

pub fn hex(&self) -> Result<String, ErrorInfo>

source

pub fn hex_or(&self) -> String

source

pub fn bytes(&self) -> Result<Vec<u8>, ErrorInfo>

source

pub fn short_id(&self) -> String

source

pub fn address(&self) -> Result<Address, ErrorInfo>

source

pub fn from_hex(hex: impl Into<String>) -> Result<Self, ErrorInfo>

source

pub fn vec(&self) -> Vec<u8>