pub struct Signature {
    pub bytes: Option<BytesData>,
    pub signature_type: i32,
}
The raw data associated with a signature, along with type information for how to verify it. Does not include the public key associated with the signature, which is stored separately (unless the signature type contains recovery id within the bytes.)

Fields

bytes: Option<BytesData>signature_type: i32

Implementations

source

impl Signature

source

pub fn signature_type(&self) -> SignatureType

Returns the enum value of signature_type, or the default if the field is set to an invalid enum value.

source

pub fn set_signature_type(&mut self, value: SignatureType)

Sets signature_type to the provided enum value.

source

impl Signature

source

pub fn ecdsa(bytes: Vec<u8>) -> Self

source

pub fn hardware(bytes: Vec<u8>) -> Self