pub struct StructMetadata {
    pub time: Option<i64>,
    pub version: i32,
    pub hash: Option<Hash>,
    pub signable_hash: Option<Hash>,
    pub signed_hash: Option<Hash>,
    pub counter_party_hash: Option<Hash>,
    pub confirmation_hash: Option<Hash>,
}
Information about the data type itself, such as time produced and hash representations of it

Fields

time: Option<i64>

If present, represents some time related information that should be signed, typically transaction origination time

version: i32

The version of the object, used for backwards / forward compatability and to determine which fields are present

hash: Option<Hash>

The hash of the present object data, including all relevant fields, but excluding any enriched / hydrated data fields This can be any one of the below hash values, and reflects the current state of the object.

signable_hash: Option<Hash>

The hash of the object data, excluding any witness information, object should be cleared of other fields or hydration related fields before signing. This is equivalent to the SegWit hash.

signed_hash: Option<Hash>

The hash of the object after being signed once, this is the hash that includes the witness data / signature data. This is equivalent to the hash of a transaction containing witness data ala standard ETH transaction.

counter_party_hash: Option<Hash>

The hash of the object after being signed twice, includes witness data from a counter-signature from an accepting party. Used for transaction contracts that require counter party acceptance

confirmation_hash: Option<Hash>

The hash of the object after being signed three times, includes witness data from original signer, counter-signer accepting party, and a final signature from the original of the counter party hashed object.

Implementations

source

impl StructMetadata

source

pub fn time(&self) -> i64

Returns the value of time, or the default value if time is unset.