pub struct TransactionContract {
    pub confirmation: Option<bool>,
    pub confirmation_proofs: Vec<Proof>,
    pub finalize_window: Option<u64>,
    pub lock_period: Option<u64>,
    pub network_reversible: Option<bool>,
    pub time_lock_window: Option<TimeLockWindow>,
    pub options: Vec<KeyValueOption>,
    pub pow_proof: Option<PoWProof>,
}

Fields

confirmation: Option<bool>

input gets signed with a proof; output gets signed with a counter-party proof; transaction then should this confirmation thing be on the output or the transaction??? Transaction

confirmation_proofs: Vec<Proof>finalize_window: Option<u64>

How long the network / each node must wait between PENDING and finalization

lock_period: Option<u64>

How long the network must wait after FINALIZED to use.

network_reversible: Option<bool>

Used to allow network criteria to vote on reversing in event of hacking.

time_lock_window: Option<TimeLockWindow>options: Vec<KeyValueOption>pow_proof: Option<PoWProof>

Used only for anti-spam limiting at low limits.

Implementations

source

impl TransactionContract

source

pub fn confirmation(&self) -> bool

Returns the value of confirmation, or the default value if confirmation is unset.

source

pub fn finalize_window(&self) -> u64

Returns the value of finalize_window, or the default value if finalize_window is unset.

source

pub fn lock_period(&self) -> u64

Returns the value of lock_period, or the default value if lock_period is unset.

source

pub fn network_reversible(&self) -> bool

Returns the value of network_reversible, or the default value if network_reversible is unset.