Struct redgold_schema::structs::TransactionInfo
source · pub struct TransactionInfo {
pub transaction: Option<Transaction>,
pub observation_proofs: Vec<ObservationProof>,
pub valid_utxo_index: Vec<i32>,
pub used_outputs: Vec<UsedOutputs>,
pub accepted: bool,
pub rejection_reason: Option<ErrorInfo>,
pub queried_output_index_valid: Option<bool>,
pub state: i32,
}Fields
transaction: Option<Transaction>observation_proofs: Vec<ObservationProof>valid_utxo_index: Vec<i32>Which output indexes are still considered valid.
used_outputs: Vec<UsedOutputs>In order to calculate this quantity, we need another index to determine if something has been used.
accepted: boolrejection_reason: Option<ErrorInfo>queried_output_index_valid: Option<bool>Move this outside to the class / request that requires it for resolving.
state: i32Implementations
sourceimpl TransactionInfo
impl TransactionInfo
sourcepub fn queried_output_index_valid(&self) -> bool
pub fn queried_output_index_valid(&self) -> bool
Returns the value of queried_output_index_valid, or the default value if queried_output_index_valid is unset.
sourcepub fn state(&self) -> TransactionState
pub fn state(&self) -> TransactionState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
sourcepub fn set_state(&mut self, value: TransactionState)
pub fn set_state(&mut self, value: TransactionState)
Sets state to the provided enum value.