pub struct TrustData {
    pub label_rating: Option<i64>,
    pub confidence: Option<i64>,
    pub hardness: Option<i64>,
    pub data: Option<StandardData>,
    pub allow_model_override: bool,
    pub rating_type: Option<i32>,
}

Fields

label_rating: Option<i64>

A score from -1 to 1 normalized to 1e3 (1000) scale for Equality avoidance of floats Otherwise equivalent to a rounded float

confidence: Option<i64>

Confidence level associated with the label, how certain is this value?

hardness: Option<i64>

Variance associated with the confidence estimate, sigma / stddev

data: Option<StandardData>

Additional unstructured or otherwise custom label data

allow_model_override: boolrating_type: Option<i32>

Implementations

source

impl TrustData

source

pub fn label_rating(&self) -> i64

Returns the value of label_rating, or the default value if label_rating is unset.

source

pub fn confidence(&self) -> i64

Returns the value of confidence, or the default value if confidence is unset.

source

pub fn hardness(&self) -> i64

Returns the value of hardness, or the default value if hardness is unset.

source

pub fn rating_type(&self) -> RatingType

Returns the enum value of rating_type, or the default if the field is unset or set to an invalid enum value.

source

pub fn set_rating_type(&mut self, value: RatingType)

Sets rating_type to the provided enum value.

source

impl TrustData

source

pub fn with_label(&mut self, label: f64) -> &mut Self

source

pub fn label(&self) -> f64

source

pub fn maybe_label(&self) -> Option<f64>

source

pub fn from_label(label: f64) -> Self