pub struct TypedValue {
    pub bytes_value: Option<BytesData>,
    pub string_value: Option<String>,
    pub uint64_value: Option<u64>,
    pub int64_value: Option<i64>,
    pub float_value: Option<String>,
    pub double_value: Option<String>,
    pub bool_value: Option<bool>,
}
Generically typed value class, used for representing arbitrary data

Fields

bytes_value: Option<BytesData>string_value: Option<String>uint64_value: Option<u64>int64_value: Option<i64>float_value: Option<String>

Used to avoid Eq comparison problem in rust for strings encoded from floats. Can also use bytes_value, but this is easier to read.

double_value: Option<String>bool_value: Option<bool>

Implementations

source

impl TypedValue

source

pub fn uint64_value(&self) -> u64

Returns the value of uint64_value, or the default value if uint64_value is unset.

source

pub fn string_value(&self) -> &str

Returns the value of string_value, or the default value if string_value is unset.

source

pub fn double_value(&self) -> &str

Returns the value of double_value, or the default value if double_value is unset.

source

pub fn int64_value(&self) -> i64

Returns the value of int64_value, or the default value if int64_value is unset.

source

pub fn bool_value(&self) -> bool

Returns the value of bool_value, or the default value if bool_value is unset.

source

pub fn float_value(&self) -> &str

Returns the value of float_value, or the default value if float_value is unset.

source

impl TypedValue

source

pub fn bytes(bytes: &Vec<u8>) -> Self