pub struct UtxoConflictResolveRequest {
pub utxo_ids: Vec<UtxoId>,
pub transaction_hash: Option<Hash>,
}Fields
utxo_ids: Vec<UtxoId>transaction_hash: Option<Hash>Trait Implementations
sourceimpl Clone for UtxoConflictResolveRequest
impl Clone for UtxoConflictResolveRequest
sourcefn clone(&self) -> UtxoConflictResolveRequest
fn clone(&self) -> UtxoConflictResolveRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for UtxoConflictResolveRequest
impl Debug for UtxoConflictResolveRequest
sourceimpl Default for UtxoConflictResolveRequest
impl Default for UtxoConflictResolveRequest
sourceimpl<'de> Deserialize<'de> for UtxoConflictResolveRequest
impl<'de> Deserialize<'de> for UtxoConflictResolveRequest
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for UtxoConflictResolveRequest
impl Hash for UtxoConflictResolveRequest
sourceimpl Message for UtxoConflictResolveRequest
impl Message for UtxoConflictResolveRequest
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where B: BufMut, Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8>where Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where B: Buf, Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where B: Buf, Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.sourceimpl PartialEq for UtxoConflictResolveRequest
impl PartialEq for UtxoConflictResolveRequest
sourcefn eq(&self, other: &UtxoConflictResolveRequest) -> bool
fn eq(&self, other: &UtxoConflictResolveRequest) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for UtxoConflictResolveRequest
impl StructuralEq for UtxoConflictResolveRequest
impl StructuralPartialEq for UtxoConflictResolveRequest