Struct redgold_schema::structs::UtxoId
source · pub struct UtxoId {
pub transaction_hash: Option<Hash>,
pub output_index: i64,
}Expand description
Standard UTXO identifier similar to Bitcoin schema.
Fields
transaction_hash: Option<Hash>The hash associated with a parent / ancestor transaction which has already been accepted as valid.
output_index: i64The index of the output in the parent transaction which is being spent / consumed.
Implementations