pub struct VersionInfo {
    pub executable_checksum: String,
    pub commit_hash: Option<String>,
    pub next_executable_checksum: Option<String>,
    pub next_upgrade_time: Option<i64>,
}
Used to store the version of the executable and the commit hash of the source code used to build it. Security verifications associated with the node software should be done with this message.

Fields

executable_checksum: String

The value associated with the Sha2-256 hash of the executable calculated with shasum locally Should match github release page.

commit_hash: Option<String>

This is only really useful in the security scenario where the node is building from source Otherwise, even if filled with a value from git, it’s not really verified

next_executable_checksum: Option<String>

Same as prior hash except the intended upgrade hash of a node, not yet used.

next_upgrade_time: Option<i64>

Intended time for performing a software update, for coordination of upgrades (not yet used.)

Implementations

source

impl VersionInfo

source

pub fn commit_hash(&self) -> &str

Returns the value of commit_hash, or the default value if commit_hash is unset.

source

pub fn next_executable_checksum(&self) -> &str

Returns the value of next_executable_checksum, or the default value if next_executable_checksum is unset.

source

pub fn next_upgrade_time(&self) -> i64

Returns the value of next_upgrade_time, or the default value if next_upgrade_time is unset.