Enum redgold_schema::structs::SignatureType
source · #[repr(i32)]pub enum SignatureType {
Ecdsa = 0,
EcdsaBitcoinSignMessageHardware = 1,
}Expand description
The verification type associated with a signature. Denotes common patterns, i.e. the default common ECDSA curve and parameters, or a custom curve denoted by a particular enum, or a particular signing algorithm. Each specific curve type or signing algorithm should be assigned it’s own enum here, so that the signing flow can be recreated from a single reference.
Variants
Ecdsa = 0
The most common secp256k1 curve used for Bitcoin and Ethereum, corresponds to the standard ECDSA signature used by most hardware / software wallets
EcdsaBitcoinSignMessageHardware = 1
The same curve as above, but following the Bitcoin Message signing strategy in order to make use of existing hardware cold wallets, can be deprecated once hardware wallet support is added for native signatures matching Redgold schema.
Implementations