Struct redgold_schema::structs::LiquidityRequest
source · pub struct LiquidityRequest {
pub deposit: Option<LiquidityDeposit>,
pub withdrawal: Option<LiquidityWithdrawal>,
}Expand description
Request to update external liquidity to a native pool
Fields
deposit: Option<LiquidityDeposit>A marker for a future external (native to the external currency,) deposit to a multiparty AMM-like pool
withdrawal: Option<LiquidityWithdrawal>A withdrawl request, indicating to the pool to send funds to the specified external chain address