Struct redgold_schema::structs::PublicKey
source · pub struct PublicKey {
pub bytes: Option<BytesData>,
pub key_type: i32,
}Expand description
Compressed public key byte data (33 bytes for standard ECDSA)
Fields
bytes: Option<BytesData>Encoded data form of the public key, requires a library for decoding to appropriate key instance
key_type: i32The type of public key, used to determine how to decode the bytes into a key instance
Implementations
sourceimpl PublicKey
impl PublicKey
sourcepub fn key_type(&self) -> PublicKeyType
pub fn key_type(&self) -> PublicKeyType
Returns the enum value of key_type, or the default if the field is set to an invalid enum value.
sourcepub fn set_key_type(&mut self, value: PublicKeyType)
pub fn set_key_type(&mut self, value: PublicKeyType)
Sets key_type to the provided enum value.
sourceimpl PublicKey
impl PublicKey
pub fn from_bytes(bytes: Vec<u8>) -> Self
pub fn hex(&self) -> Result<String, ErrorInfo>
pub fn hex_or(&self) -> String
pub fn bytes(&self) -> Result<Vec<u8>, ErrorInfo>
pub fn short_id(&self) -> String
pub fn address(&self) -> Result<Address, ErrorInfo>
pub fn from_hex(hex: impl Into<String>) -> Result<Self, ErrorInfo>
pub fn vec(&self) -> Vec<u8>