Struct redgold_schema::structs::StandardData
source · pub struct StandardData {Show 19 fields
pub amount: Option<CurrencyAmount>,
pub generic_typed_value: Option<GenericTypedValue>,
pub peer_data: Option<PeerMetadata>,
pub node_metadata: Option<NodeMetadata>,
pub dynamic_node_metadata: Option<DynamicNodeMetadata>,
pub height: Option<i64>,
pub data_hash: Option<Hash>,
pub hash: Option<Hash>,
pub observation: Option<Observation>,
pub address: Option<Address>,
pub state: Option<BytesData>,
pub request: Option<BytesData>,
pub standard_request: Option<StandardRequest>,
pub liquidity_request: Option<LiquidityRequest>,
pub portfolio_info: Option<PortfolioInfo>,
pub schema_def: Option<SchemaDef>,
pub data: Option<BytesData>,
pub aggregate_state_hash: Option<Hash>,
pub external_transaction_id: Option<ExternalTransactionId>,
}Expand description
Generic data structure designed to hold arbitrary data in a common format. This should be considered supplementary to using a regular schema, not a complete substitute.
Fields
amount: Option<CurrencyAmount>Standard currency style field
generic_typed_value: Option<GenericTypedValue>peer_data: Option<PeerMetadata>Where a peer (representing a person controlling multiple nodes from a cold wallet,) updates it’s metadata within a transaction
node_metadata: Option<NodeMetadata>Where an online or live node programmatically updates it’s own metadata using it’s live hot keys
dynamic_node_metadata: Option<DynamicNodeMetadata>Latest value associated with the online / hot node – updated more frequently and not necessarily tracked in every transaction, but kept here for reference.
height: Option<i64>Equivalent to ‘block height’, linear observation counter
data_hash: Option<Hash>Reference to externally resolved data
hash: Option<Hash>Pure hash reference, without necessarily being backed by any specific data.
observation: Option<Observation>Used for node transactions related to their internal observation formation, equivalent to a ‘local’ block
address: Option<Address>Used for referencing bitcoin address, kept here at top level for convenience
state: Option<BytesData>Used to store state information directly following eUTXO conventions
request: Option<BytesData>Contract style request, similar to Ethereum transaction for updating a smart contract, from an external user
standard_request: Option<StandardRequest>Contract style response, similar to above, but specifically typed to correspond to a ‘default’ schema driven request common to all contracts and available automatically in the SDK.
liquidity_request: Option<LiquidityRequest>Staking request, designed for use with the native AMM/Portfolio functions.
portfolio_info: Option<PortfolioInfo>Portfolio information, used for updating the current ‘target’ state of a portfolio
schema_def: Option<SchemaDef>Schema definition for the data, used for parsing and validation
data: Option<BytesData>Generic bytes data, used for storing arbitrary data
aggregate_state_hash: Option<Hash>For eUTXO style contracts, the hash of all state information aggregated from initial state origin. Can be re-calculated.
external_transaction_id: Option<ExternalTransactionId>A bitcoin txid for example
Implementations
sourceimpl StandardData
impl StandardData
sourceimpl StandardData
impl StandardData
pub fn observation(o: Observation) -> Self
pub fn empty() -> Self
pub fn peer_data(pd: PeerMetadata) -> Option<Self>
pub fn amount_data(amount: u64) -> Option<Self>