Struct redgold_schema::structs::SubmitTransactionResponse
source · pub struct SubmitTransactionResponse {
pub transaction_hash: Option<Hash>,
pub query_transaction_response: Option<QueryTransactionResponse>,
pub transaction: Option<Transaction>,
}Expand description
TODO: This should just return the entire transaction with it’s hash also calculated Also include the signing hash in the response, modify transaction schema for that
Fields
transaction_hash: Option<Hash>query_transaction_response: Option<QueryTransactionResponse>transaction: Option<Transaction>Implementations
sourceimpl SubmitTransactionResponse
impl SubmitTransactionResponse
pub fn accepted(&self, expected_count: usize) -> Result<(), ErrorInfo>
pub fn pending(&self, expected_count: usize) -> Result<(), ErrorInfo>
pub fn check_by_state( &self, expected_count: usize, state: State ) -> Result<(), ErrorInfo>
pub fn unique_by_state(&self) -> Result<HashSet<(&PublicKey, i32)>, ErrorInfo>
pub fn count_unique_by_state(&self) -> Result<HashMap<i32, usize>, ErrorInfo>
pub fn at_least_1(&self) -> Result<(), ErrorInfo>
pub fn at_least_n(&self, n: usize) -> Result<(), ErrorInfo>